@@ -1,8 +1,8 @@
 /* pkginfo.c - Retrieve information about packages for deborphan.
    Copyright (C) 2000, 2001, 2002, 2003 Cris van Pelt
-   Copyright (C) 2003, 2004 Peter Palfrader
+   Copyright (C) 2003, 2004, 2006 Peter Palfrader
 
-   $Id: pkginfo.c 499 2004-10-01 21:50:01Z weasel $
+   $Id: pkginfo.c 577 2006-10-05 16:33:10Z weasel $
 
    Distributed under the terms of the Artistic License.
 */
@@ -50,9 +50,9 @@ init_pkg_regex()
 	if (guess_chk(GUESS_PERL))
 	    strcat(guess, "^lib.*-perl$|");
 	if (guess_chk(GUESS_PYTHON))
-	    strcat(guess, "^python[[:digit:]]*-|");
+	    strcat(guess, "^python[[:digit:].]*-|");
 	if (guess_chk(GUESS_PIKE))
-	    strcat(guess, "^pike[[:digit:]]*-|");
+	    strcat(guess, "^pike[[:digit:].]*-|");
 	if (guess_chk(GUESS_RUBY))
 	    strcat(guess, "^lib.*-ruby$|");
 	if (guess_chk(GUESS_DEV))
